@@ -5,7 +5,7 @@ data(chipExampleBig)
 p <- as_profileplyr(chipExampleBig,names = "name")
 export_deepToolsMat(p,con = "p.MAT")
 export_deepToolsMat(p[,,1],con = "pSingle.MAT")
-expect_that(file.exists("p.MAT.gz"),is_true())
-expect_that(file.exists("pSingle.MAT.gz"),is_true())
+expect_true(file.exists("p.MAT.gz"))
+expect_true(file.exists("pSingle.MAT.gz"))
 unlink("p.MAT.gz")
 unlink("pSingle.MAT.gz")
